// This is a JavaScript module that is loaded on demand. It can export any number of
// functions, and may import other JavaScript modules if required.

export function initialize(lastItemIndicator, direction, componentInstance) {

    var isFirstEvent = true;

    const options = {
        root: findClosestScrollContainer(lastItemIndicator),
        rootMargin: '0px',
        threshold: 0,
    };

    const observer = new IntersectionObserver(async (entries) => {

        // When the lastItemIndicator element is visible => invoke the C# method `LoadMoreItems`
        if (!isFirstEvent) {

            let rootElement = findClosestScrollContainer(lastItemIndicator);
            let oldScrollHeight = rootElement.scrollHeight;

            for (const entry of entries) {
                if (entry.isIntersecting) {

                    await componentInstance.invokeMethodAsync("LoadMoreItems");

                    // If BottomToTop
                    if (direction == 1) {

                        let top = rootElement.scrollHeight - oldScrollHeight;
                        rootElement.scrollTo({ top: top, left: 0, behavior: "instant" });
                    }
                }
            }
        }

        isFirstEvent = false;

    }, options);

    observer.observe(lastItemIndicator);

    // Allow to cleanup resources when the Razor component is removed from the page
    return {
        dispose: () => dispose(observer),
        onNewItems: () => {
            observer.unobserve(lastIndicator);
            observer.observe(lastIndicator);
        },
    };
}

export function scrollToEnd(element) {
    element = findClosestScrollContainer(element);
    element.scrollTo({ top: element.scrollHeight, left: 0, behavior: "instant" });
}

export function scrollToTop(element) {
    element = findClosestScrollContainer(element);
    element.scrollTo({ top: 0, left: 0, behavior: "instant" });
}

export function scrollIntoView(id) {

    let element = document.getElementById(id);
    
    if (element) {
    
        element.scrollIntoView();
    }
}

// Find the parent element with a vertical scrollbar
// This container should be use as the root for the IntersectionObserver
export function findClosestScrollContainer(element) {
    while (element) {
        const style = getComputedStyle(element);
        if (style.overflowY !== 'visible') {
            return element;
        }
        element = element.parentElement;
    }
    return null;
}

// Cleanup resources
export function dispose(observer) {
    observer.disconnect();
}